/******************************************************************************
*
*      FILE: qs_sl.h
*   VERSION: 4.00
*      DATE: May 2009
* COPYRIGHT: QAS Ltd
*
* C sample code for integrating the QAS Pro Single Line search engine (V4.x).
*
* This file contains all definitions and prototypes relating to the associated
* sample code. See qs_sl.c for more information.
*
******************************************************************************/


/**** Standard C library headers ****/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>

/**** QAS Pro API header ****/

#include "qaupied.h"

/**** Constants ****/

#define DATASET_LENGTH          20      /* Length of string containing data set ISO code */
#define DATANAME_LENGTH         30      /* Length of string containing data set name */
#define SEARCH_LENGTH           150     /* Generic buffer length for search and address related information */
#define ERROR_LENGTH            100     /* Length of buffer for displaying error messages */

#define ADDRESS_RESULT_WIDTH    50      /* Width of address column in displayed picklists */



/**************
* Search_t
*
* Search context structure. This structure is used to maintain the search
* context during the address capture process. It can be modified or extended
* as required.
*
* Members:
*
*   iHandle   : This is the handle to QAS Pro API. A value of -1 indicates that
*               the API is currently shutdown.
*
*   iLevel    : The picklist level. The first picklist stage is level 0. Each
*               subsequent step-in results in the level being incremented. A
*               value of -1 indicates that no results are available or the user
*               has aborted the address capture process.
*
*   iAddress  : The selected (leaf-node) address. This will be set to -1 whilst
*               the user is navigating the picklists. Once a leaf-node address
*               has been selected this will be set to the offset of the picklist
*               item.
*
*   asHistory : Search history. This contains details of original search
*               expression and the picklist items that have been stepped into.
*               This information is displayed to the user to give them "context"
*               for the current picklist.
*
**************/

typedef struct tagSearch
{
    int     iHandle;
    int     iLevel;
    int     iAddress;
    char    asHistory [10][SEARCH_LENGTH];
}
Search_t;



/**** Function definitions from qs_sl.c ****/

int  QS_Startup             (Search_t *ptSearch, char *psDataSet);
void QS_Shutdown            (Search_t *ptSearch);
int  QS_SingleLineSearch    (Search_t *ptSearch, char *psDataSet, char *psSearch);
void QS_EndSearch           (Search_t *ptSearch);
int  QS_UpdatePickList      (Search_t *ptSearch, int iAvailable, int iPotential);
int  QS_SelectPickListItem  (Search_t *ptSearch, int iAvailable, int iIndex);
int  QS_FormatAddress       (Search_t *ptSearch);


/**** Function prototypes from qs_sl_io.c ****/

void QS_ReportError             (Search_t *ptSearch, int iError, char *psMessage);
int  QS_GetSearchParameters     (Search_t *ptSearch, char *psDataSet, char *psSearch);
void QS_GetLayoutParameter      (char *psLayout);
void QS_ViewDataSets            (Search_t *ptSearch);
void QS_ViewSystemInfo          (Search_t *ptSearch);
int  QS_NavigatePickLists       (Search_t *ptSearch);
void QS_StartPickListDisplay    (Search_t *ptSearch, int iPotential);
int  QS_DisplayAddress          (Search_t *ptSearch, int iCount);
void QS_DisplayPickListItem     (char *psAddress);
void QS_DisplayMessage          (char *psMessage);





/******************************************************************************
******************* End of file qs_sl.h ***************************************
******************************************************************************/
